#!/usr/bin/env python
#==============================================================================
# Copyright and license info is available in the LICENSE file included with
# the Server Deployment Package (SDP), and also available online:
# https://swarm.workshop.perforce.com/projects/perforce-software-sdp/view/main/LICENSE
#------------------------------------------------------------------------------

"""
This script will unload labels that have not been accessed since the number
of weeks specified in the removedate string below.
"""

# Python 2.7/3.3 compatibility.
from __future__ import print_function

import os
import datetime
import platform
import sys

if len(sys.argv) > 1:
  SDP_INSTANCE = str(sys.argv[1])
else:
  SDP_INSTANCE = '1'

# Python 2.7/3.3 compatibility.
if sys.version_info[0] >= 3:
    import configparser
    config = configparser.RawConfigParser()
else:
    import ConfigParser
    config = ConfigParser.RawConfigParser()
config.read('maintenance.cfg')

##########################################################################
#####                                                                #####
#####  CONFIGURATION VARIABLES: Modify in maintenance.cfg as needed. #####
#####                                                                #####

server = (config.get(SDP_INSTANCE, 'server'))
p4user = (config.get(SDP_INSTANCE, 'p4user'))
passwd = (config.get(SDP_INSTANCE, 'passwd'))
weeks = int(config.get(SDP_INSTANCE, 'weeks'))

if platform.system() == "Windows": 
  p4="p4.exe -p %s -u %s" % (server, p4user)
else:
  p4="/p4/%s/bin/p4_%s  -p %s -u %s" % (SDP_INSTANCE, SDP_INSTANCE, server, p4user)

def main():
  removedate = (datetime.date.today() - datetime.timedelta(weeks)).strftime("%Y/%m/%d")
  command = ('%s unload -f -L -z -al -d %s') % (p4, removedate)
  os.system(command)
  
###############################################################################
# main
if __name__ == '__main__':
  main()
